
*******************************************************************************

* GENERAL INFO
	* Project: Who's Asking? Interviewer Coethnicity Effects in African Survey Data
	* Created: by Claire Adida, Karen Ferree, Dan Posner, and Amanda Robinson
	* Updated: 9 Mar 16 by Julia Clark

* DO FILE INFO
	* This .do file runs executes the data analysis and creates graphs and tables
	* Required .do files: AFPR_clean.do, clean_3.do, clean_4.do, q79label.do
	* Inputs: AFPR_final.dta, AFPR_clean.do, outcome_labels.dta
	* Outputs: tables and graphs from paper

*******************************************************************************

* SETUP

	clear all
	set more off
	set matsize 800
	
* DIRECTORY: set to location of replication folder

	capture cd "~/Dropbox/AFPR_replication_files"

* PACKAGES
	*ssc install labutil
	*ssc install distinct
	*ssc install center
	*ssc install tabout
	*ssc install sencode
	*ssc install outreg2
	
* CLEAN DATA

	qui: run "code/AFPR_clean.do"	

*******************************************************************************

* LOAD DATA

	set more off
	use "data/AFPR_final.dta", clear

* DEFINE OUTCOMES AND CONTROLS

	global eth_outcomes idrank patronage etrust netrust ecconditions_group polinfluence_group treatedunfairly_group 
	global pol_outcomes demosupp performance bribe1 ec_conditions_ctry trust_rulingparty trust_opposition  gov_manage_economy voted pubaffairs meeting knows_MP  
	global stat_outcomes ec_conditions_self notenoughfood noincome nocleanwater crime aids
	global pro_outcomes hostile uncooperative impatient suspicious
	global outcomes $eth_outcomes $pol_outcomes $stat_outcomes $pro_outcomes 

	distinct tribe region enumeth country
	global tribes tribe1-tribe282 // 282 tribes
	global regions region1-region172 // 172 regions
	global enumtribes enumtribe1-enumtribe129 // 129 enum tribes
	global countries country1-country14 // 14 countries

	global fe1 $countries
	global fe2 $regions
	global fe3 $regions $tribes
	global fe4 $regions $tribes $enumtribes
	global fes fe1 fe2 fe3 fe4
	
*******************************************************************************

* ASSIGNMENT TO TREATMENT (pooled)

* generate Table 1: Assignment to Treatment (Interviewed by Non-Coethnic) 
	reg noncoeth gender age edu Round4 urban minority $countries, vce(robust)
		outreg2 using "output/ATT.xls", keep(gender age edu Round4 urban minority) replace excel title("Pooled Assignment to Treatment Analysis") ctitle(State FE) label bdec(2)  sdec(2) rdec(2) stats(coef se)
	reg noncoeth gender age edu Round4 urban minority ethsize ethsize2 enum_ethsize enum_ethsize2 $regions, vce(robust)
		outreg2 using "output/ATT.xls", keep(gender age edu Round4 urban minority ethsize ethsize2 enum_ethsize enum_ethsize2) excel ctitle("Region FE") label append bdec(2)  sdec(2) rdec(2) stats(coef se)
	reg noncoeth gender age edu Round4 urban minority ethsize ethsize2 enum_ethsize enum_ethsize2 $regions $tribes, vce(robust)
		outreg2 using "output/ATT.xls", keep(gender age edu Round4 urban minority enum_ethsize enum_ethsize2) excel ctitle("Region & R's Group FE") label append bdec(2)  sdec(2) rdec(2) stats(coef se)
	reg noncoeth gender age edu Round4 urban minority ethsize ethsize2 enum_ethsize enum_ethsize2 $regions  $tribes $enumtribes,  vce(robust)
		outreg2 using "output/ATT.xls", keep(gender age edu Round4 urban minority ) excel ctitle("Region & R Group FE & E Group FE") label append bdec(2)  sdec(2) rdec(2) stats(coef se)

*******************************************************************************

* MAIN EFFECTS

* create temp files for output, graphing
	set more off
	tempfile pooled 
	tempname main				   
	postfile `main' str30 type str30 outcome str30 specification str30 sample b se n df using `pooled', replace

* models
	* ethnic
		foreach y in $eth_outcomes {
			areg z_`y' noncoeth, abs(country) vce(robust)
			post `main' ("Ethnic") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang, abs(region)  vce(robust)
			post `main' ("Ethnic") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3, vce(robust)
			post `main' ("Ethnic") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, vce(robust)
			post `main' ("Ethnic") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		}

	* political
		foreach y in $pol_outcomes {
			areg z_`y' noncoeth, abs(country) vce(robust)
			post `main' ("Political") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2  inhomelang, abs(region) vce(robust)
			post `main' ("Political") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3, vce(robust)
			post `main' ("Political") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, vce(robust)
			post `main' ("Political") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		}

	* individual ses
		foreach y in $stat_outcomes {
			areg z_`y' noncoeth, abs(country) vce(robust)
			post `main' ("SES") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang, abs(region) vce(robust)
			post `main' ("SES") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3 ,  vce(robust)
			post `main' ("SES") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , vce(robust)
			post `main' ("SES") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		}

	* procedural
		foreach y in $pro_outcomes {
			areg z_`y' noncoeth, abs(country) vce(robust)
			post `main' ("Procedural") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang, abs(region) vce(robust)
			post `main' ("Procedural") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3 , vce(robust)
			post `main' ("Procedural") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
			reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , vce(robust)
			post `main' ("Procedural") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}

	postclose `main' 
	use `pooled', clear

	replace specification="1" if specification=="Bivariate"
	replace specification="2" if specification=="FE2"
	replace specification="3" if specification=="FE3"
	replace specification="4" if specification=="FE4"

* calculate p values and confidence intervals
	gen t = b/se
	gen p= 2*ttail(df, abs(t))
	gen sig="*" if p<0.1 & p~=.
		replace sig="**" if p<0.05 & p~=.
		replace sig="***" if p<0.01 & p~=.
	gen min95=b - invttail(df,0.025)*se
	gen max95=b + invttail(df,0.025)*se

* merge in outcome labels
	gen order=_n
	merge m:1 outcome using "data/outcome_labels.dta"
	drop _merge
	order outcome type specification sample label shortlab
	sort order
	drop order

* save results for Table A3: The Effect of a Non-Coethnic Interviewer on Survey Responses in 14 African Countries 
	export delimited using "output/pooled.csv", replace	

* generate graphs
	keep if specification=="4"
	
	gen id=_n
	replace id=id*-1
	sort id
	sencode shortlab, gen(y)
		
	* FIGURE 1. Impacts of a Non-Coethnic Interviewer on Responses to Ethnic Questions 
	twoway (rspike min95 max95 y if sample=="Pooled" & type=="Ethnic", hor lc(black) lw(thin)) ///
		(scatter y b if sample=="Pooled" & type=="Ethnic", msize(small) ms(O) mfc(black) mlc(black)) ///
		, ///
		legend(off) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#7, angle(horizontal) valuelabel labs(3.2) nogrid ) ///
		xlabel(#6, labs(3.2)) ///
		xline(0, lpattern(shortdash)) ///
		xscale(r(-0.15 0.15)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(3.2)) ytitle("") ///
		graphregion(margin(l=55 b=5))
		graph export "output/ethnic_pooled.pdf", replace	
	
	* FIGURE 2. Impacts of a Non-Coethnic Interviewer on Responses to Political Questions 
	twoway (rspike min95 max95 y if sample=="Pooled" & type=="Political", hor lc(black) lw(thin)) ///
		(scatter y b if sample=="Pooled" & type=="Political", msize(small) ms(O) mfc(black) mlc(black)) ///
		, ///
		legend(off) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#11, angle(horizontal) valuelabel labs(3.2) nogrid ) ///
		xlabel(#6, labs(3.2)) ///
		xline(0, lpattern(shortdash)) ///
		xscale(r(-0.15 0.15)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(3.2)) ytitle("") ///
		graphregion(margin(l=55 b=5))
		graph export "output/political_pooled.pdf", replace	

	* FIGURE 3. Impacts of a Non-Coethnic Interviewer on Responses to Economic Questions 
	twoway (rspike min95 max95 y if sample=="Pooled" & type=="SES", hor lc(black) lw(thin)) ///
		(scatter y b if sample=="Pooled" & type=="SES", msize(small) ms(O) mfc(black) mlc(black)) ///
		, ///
		legend(off) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#6, angle(horizontal) valuelabel labs(3.2) nogrid ) ///
		xlabel(#6, labs(3.2)) ///
		xline(0, lpattern(shortdash)) ///
		xscale(r(-0.15 0.15)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(3.2)) ytitle("") ///
		graphregion(margin(l=0 b=5))
		graph export "output/ses_pooled.pdf", replace	
		
	* FIGURE 4. Impacts of a Non-Coethnic Interviewer on Interviewer's Reports of Respondent's Demeanor	
	twoway (rspike min95 max95 y if sample=="Pooled" & type=="Procedural", hor lc(black) lw(thin)) ///
		(scatter y b if sample=="Pooled" & type=="Procedural", msize(small) ms(O) mfc(black) mlc(black)) ///
		, ///
		legend(off) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#4, angle(horizontal) valuelabel labs(3.2) nogrid ) ///
		xlabel(#6, labs(3.2)) ///
		xline(0, lpattern(shortdash)) ///
		xscale(r(-0.15 0.15)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(3.2)) ytitle("") ///
		graphregion(margin(l=0 b=5))
		graph export "output/procedural_pooled.pdf", replace	


*******************************************************************************

* SA RACE EFFECTS 

	use "data/AFPR_final.dta", clear
	set more off

* create temp files for output, graphing
	keep if safrica==1
	tempfile southafrica
	tempname race
	postfile `race' str30 outcome str30 specification str30 sample b se n df using `southafrica', replace	

* models
		foreach y in $outcomes {
			areg co_`y' enum_african age gender edu urban minority Round4  inhomelang $regions if race==2 & enum_coloured~=1, abs(tribe) vce(robust)
			post `race'  ("`y'") ("Full") ("Whites") (_b[enum_african]) (_se[enum_african]) (e(N)) (e(df_r))
			areg co_`y' enum_white  age gender edu urban minority Round4  inhomelang $regions if race==1 & enum_coloured~=1, abs(tribe) vce(robust)
			post `race'  ("`y'") ("Full") ("Black Africans") (_b[enum_white]) (_se[enum_white]) (e(N)) (e(df_r))
		}

	postclose `race' 
	use `southafrica', clear

* calculate p values and confidence intervals
	gen t = b/se
	gen p= 2*ttail(df, abs(t))
	gen sig="*" if p<0.1 & p~=.
		replace sig="**" if p<0.05 & p~=.
		replace sig="***" if p<0.01 & p~=.
	gen min95=b - invttail(df,0.025)*se
	gen max95=b + invttail(df,0.025)*se

* sort data for tables	
	gen order=_n
	gsort - sample + order
	replace order=_n

* merge in outcome labels
	merge m:1 outcome using "data/outcome_labels.dta"
	drop _merge
	order outcome specification sample label shortlab
	sort order
	drop order

* save results for Table A4: Impact of a Non-Coracial Interviewer in South Africa
	export delimited using "output/SA_race.csv", replace
	
* generate graph
	gen id=_n
	replace id=id*-1
	sort id
	sencode shortlab, gen(y)
	replace y=y + 0.25 if sample=="Black Africans"

	* FIGURE 5. Impacts of a Non-Coracial Interviewer on Survey Responses in South Africa 
	twoway (rspike min95 max95 y if sample=="Black Africans", hor lc(black) lw(thin)) ///
		(scatter y b if sample=="Black Africans", msize(small) ms(O) mfc(black) mlc(black)) ///
		(rspike min95 max95 y if sample=="Whites", hor lc(black) lw(thin)) ///
		(scatter y b if sample=="Whites", msize(small) ms(O) mc(white) mlc(black)) ///
		, ///
		legend(order(2 "Black Respondents" 4 "White Respondents") size (vsmall) row(2) region(lw(none) fc(none)) ring(1) pos(7) ) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#28, angle(horizontal) valuelabel labs(2.2) nogrid) ///
		xlabel(#6, labs(2.2)) ///
		xsize(4) ysize(8)  ///
		xline(0, lpattern(shortdash)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coracial Interviewer" "95% Confidence Intervals", size(2.2)) ytitle("") ///
		graphregion(margin(l=50 b=5))
		graph export "output/WhitesvsBlacks.pdf", replace

	

*******************************************************************************

* IMPACT OF POLITICALLY RELEVANT DYADS

	use "data/AFPR_final.dta", clear
	set more off

* create temp files for output, graphing

	tempfile dyads
	tempname prdyads
	postfile `prdyads' str30 type str30 outcome str30 specification str30 sample str30 variable b se n df using `dyads', replace	
			   
* models
	* ethnic
	foreach y in $eth_outcomes {
		reg z_`y' pr_noncoeth npr_noncoeth  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, vce(robust)
		post `prdyads' ("Ethnic") ("`y'") ("FE4") ("Pooled") ("PR noncoeth") (_b[pr_noncoeth]) (_se[pr_noncoeth]) (e(N)) (e(df_r)) 
		post `prdyads' ("Ethnic") ("`y'") ("FE4") ("Pooled") ("non-PR noncoeth") (_b[npr_noncoeth]) (_se[npr_noncoeth]) (e(N)) (e(df_r))
	}

	* political
	foreach y in $pol_outcomes {
		reg z_`y' pr_noncoeth npr_noncoeth  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, vce(robust)
		post `prdyads' ("Political") ("`y'") ("FE4") ("Pooled") ("PR noncoeth") (_b[pr_noncoeth]) (_se[pr_noncoeth]) (e(N)) (e(df_r)) 
		post `prdyads' ("Political") ("`y'") ("FE4") ("Pooled") ("non-PR noncoeth") (_b[npr_noncoeth]) (_se[npr_noncoeth]) (e(N)) (e(df_r)) 
	}

	* individual ses
	foreach y in $stat_outcomes {
		reg z_`y' pr_noncoeth npr_noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , vce(robust)
		post `prdyads' ("SES") ("`y'") ("FE4") ("Pooled") ("PR noncoeth") (_b[pr_noncoeth]) (_se[pr_noncoeth]) (e(N)) (e(df_r)) 
		post `prdyads' ("SES") ("`y'") ("FE4") ("Pooled") ("non-PR noncoeth") (_b[npr_noncoeth]) (_se[npr_noncoeth]) (e(N)) (e(df_r)) 
	}

	* procedural
	foreach y in $pro_outcomes {
		reg z_`y' pr_noncoeth npr_noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , vce(robust)
		post `prdyads' ("Procedural") ("`y'") ("FE4") ("Pooled") ("PR noncoeth") (_b[pr_noncoeth]) (_se[pr_noncoeth]) (e(N)) (e(df_r)) 
		post `prdyads' ("Procedural") ("`y'") ("FE4") ("Pooled") ("non-PR noncoeth") (_b[npr_noncoeth]) (_se[npr_noncoeth]) (e(N)) (e(df_r)) 
	}

	postclose `prdyads' 
	use `dyads', clear

* calculate p values and confidence intervals
	gen t = b/se
	gen p= 2*ttail(df, abs(t))
	gen sig="*" if p<0.1 & p~=.
		replace sig="**" if p<0.05 & p~=.
		replace sig="***" if p<0.01 & p~=.
	gen min95=b - invttail(df,0.025)*se
	gen max95=b + invttail(df,0.025)*se
		
* merge in outcome labels
	gen order=_n
	gsort - sample + order
	replace order=_n
	merge m:1 outcome using "data/outcome_labels.dta"
	drop _merge
	order outcome specification sample label shortlab
	sort order
	drop order

* save results for Table A5: Impact of Politically Relevant and Irrelevant Non-Coethnic Interviewers
	export delimited using "output/prdyads.csv", replace	
		
* generate graph
	* drop SA-specific outcomes
	foreach y in sa_first life_apartheid gov_unitesa {
		drop if outcome=="`y'"
	}

	gen id=_n
	replace id=id*-1
	sort id
	sencode shortlab, gen(y)
	replace y=y + 0.25 if variable=="PR noncoeth"

	* FIGURE 6. Impacts of Politically Relevant and Irrelevant Non-Coethnic Interviewers on Survey Responses 
	twoway (rspike min95 max95 y if variable=="PR noncoeth", hor lc(black) lw(thin)) ///
		(scatter y b if variable=="PR noncoeth", msize(small) ms(O) mfc(black) mlc(black)) ///
		(rspike min95 max95 y if variable=="non-PR noncoeth", hor lc(black) lw(thin)) ///
		(scatter y b if variable=="non-PR noncoeth", msize(small) ms(O) mc(white) mlc(black)) ///
		, ///
		legend(order(2 "Politically Relevant Non-Coethnic Dyads" 4 "Non-Politically Relevant Non-Coethnic Dyads") ///
		size (vsmall) row(2) region(lw(none) fc(none)) ring(1) pos(7) ) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#28, angle(horizontal) valuelabel labs(2.2) nogrid) ///
		xlabel(#6, labs(2.2)) ///
		xsize(4) ysize(8)  ///
		xline(0, lpattern(shortdash)) ///
		xscale(r(-0.15 0.15)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(2.2)) ytitle("") ///
		graphregion(margin(l=50 b=5))
		graph export "output/PREG.pdf", replace

	

*******************************************************************************

* IMPACT OF LEADER COETHNICITY: RESPONDENT coethnic with president

	use "data/AFPR_final.dta", clear
	set more off

* create temp files for output, graphing
	tempfile rlcoeth
	tempname leadercoeth
	postfile `leadercoeth' str30 type str30 outcome str30 specification str30 sample r_leadercoeth b se n df using `rlcoeth', replace				   

* models
	* ethnic
	foreach y in $eth_outcomes {
		areg z_`y' i.noncoeth#i.coeth_leader age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , abs(region) vce(robust)
		margins, dydx(noncoeth) by(coeth_leader) noestimcheck post
		post `leadercoeth' ("Ethnic") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.coeth_leader]) (_se[1.noncoeth:0.coeth_leader]) (e(N)) (e(df_r))  
		post `leadercoeth' ("Ethnic") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.coeth_leader]) (_se[1.noncoeth:1.coeth_leader]) (e(N)) (e(df_r)) 
	}

	* political
	foreach y in $pol_outcomes {
		areg z_`y' i.noncoeth#i.coeth_leader age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, abs(region) vce(robust)
		qui: margins, dydx(noncoeth) by(coeth_leader) noestimcheck post
		post `leadercoeth' ("Political") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.coeth_leader]) (_se[1.noncoeth:0.coeth_leader]) (e(N)) (e(df_r))  
		post `leadercoeth' ("Political") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.coeth_leader]) (_se[1.noncoeth:1.coeth_leader]) (e(N)) (e(df_r)) 
	}

	* individual ses
	foreach y in $stat_outcomes {
		areg z_`y' i.noncoeth#i.coeth_leader  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, abs(region) vce(robust)
		qui: margins, dydx(noncoeth) by(coeth_leader) noestimcheck post
		post `leadercoeth' ("SES") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.coeth_leader]) (_se[1.noncoeth:0.coeth_leader]) (e(N)) (e(df_r))  
		post `leadercoeth' ("SES") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.coeth_leader]) (_se[1.noncoeth:1.coeth_leader]) (e(N)) (e(df_r)) 
	}

	* procedural
	foreach y in $pro_outcomes {
		areg z_`y' i.noncoeth#i.coeth_leader  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, abs(region) vce(robust)
		qui: margins, dydx(noncoeth) by(coeth_leader) noestimcheck post
		post `leadercoeth' ("Procedural") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.coeth_leader]) (_se[1.noncoeth:0.coeth_leader]) (e(N)) (e(df_r))  
		post `leadercoeth' ("Procedural") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.coeth_leader]) (_se[1.noncoeth:1.coeth_leader]) (e(N)) (e(df_r)) 
	}

	postclose `leadercoeth'
	use `rlcoeth', clear

* calculate p values and confidence intervals
	gen t = b/se
	gen p= 2*ttail(df, abs(t))
	gen sig="*" if p<0.1 & p~=.
		replace sig="**" if p<0.05 & p~=.
		replace sig="***" if p<0.01 & p~=.
	gen min95=b - invttail(df,0.025)*se
	gen max95=b + invttail(df,0.025)*se
	
* merge in outcome labels
	gen order=_n
	gsort - sample + order
	replace order=_n
	
	merge m:1 outcome using "data/outcome_labels.dta"
	drop _merge
	order outcome specification sample label shortlab
	sort order
	drop order

* save results for Table A6: Impact of a Non-Coethnic Interviewer when Respondent Coethnic with Head of State
	export delimited using "output/r_leadercoeth.csv", replace

* generate graph		
	gen id=_n
	replace id=id*-1
	sort id
	sencode shortlab, gen(y)
	replace y=y + 0.25 if r_leadercoeth==1
	
	* FIGURE 7a. Impacts of Non-Coethnic Interviewers ... When Respondent is Coethnic with Head of State
	twoway (rspike min95 max95 y if r_leadercoeth==0 & type=="Political", hor lc(black) lw(thin)) ///
		(scatter y b if r_leadercoeth==0 & type=="Political", msize(small) ms(T) mc(white) mlc(black)) ///
		(rspike min95 max95 y if r_leadercoeth==1 & type=="Political", hor lc(black) lw(thin)) ///
		(scatter y b if r_leadercoeth==1 & type=="Political", msize(small) ms(T) mfc(black) mlc(black)) ///
		, ///
		legend(order(2 "Respondent NOT Coethnic with Leader" 4 "Respondent Coethnic with Leader") ///
		size (vsmall) row(3) region(lw(none) fc(none)) ring(1) pos(7) ) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#11, angle(horizontal) valuelabel labs(2.2) nogrid) ///
		xlabel(#6, labs(2.2)) ///
		xline(0, lpattern(shortdash)) ///
		xscale(r(-0.15 0.15)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(2.2)) ytitle("") ///
		graphregion(margin(l=50 b=5))
		graph export "output/r_leadercoeth.pdf", replace


*******************************************************************************

* IMPACT OF LEADER COETHNICITY: INTERVIEWER coethnic with president

	use "data/AFPR_final.dta", clear
	set more off

* create temp files for output, graphing
	tempfile elcoeth
	tempname eleadercoeth
	postfile `eleadercoeth' str30 type str30 outcome str30 specification str30 sample e_leadercoeth b se n df using `elcoeth', replace				   

* models
	* ethnic
	foreach y in $eth_outcomes {
		areg z_`y' i.noncoeth#i.int_coeth_leader  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , abs(region) vce(robust)
		qui: margins, dydx(noncoeth) by(int_coeth_leader) noestimcheck post
		post `eleadercoeth' ("Ethnic") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.int_coeth_leader]) (_se[1.noncoeth:0.int_coeth_leader]) (e(N)) (e(df_r))  
		post `eleadercoeth' ("Ethnic") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.int_coeth_leader]) (_se[1.noncoeth:1.int_coeth_leader]) (e(N)) (e(df_r)) 
	}

	* political
	foreach y in $pol_outcomes {
		areg z_`y' i.noncoeth#i.int_coeth_leader age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, abs(region) vce(robust)
		qui: margins, dydx(noncoeth) by(int_coeth_leader) noestimcheck post
		post `eleadercoeth' ("Political") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.int_coeth_leader]) (_se[1.noncoeth:0.int_coeth_leader]) (e(N)) (e(df_r))  
		post `eleadercoeth' ("Political") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.int_coeth_leader]) (_se[1.noncoeth:1.int_coeth_leader]) (e(N)) (e(df_r)) 
	}

	* individual ses
	foreach y in $stat_outcomes {
		areg z_`y' i.noncoeth#i.int_coeth_leader  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, abs(region) vce(robust)
		qui: margins, dydx(noncoeth) by(int_coeth_leader) noestimcheck post
		post `eleadercoeth' ("SES") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.int_coeth_leader]) (_se[1.noncoeth:0.int_coeth_leader]) (e(N)) (e(df_r))  
		post `eleadercoeth' ("SES") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.int_coeth_leader]) (_se[1.noncoeth:1.int_coeth_leader]) (e(N)) (e(df_r)) 
	}

	* procedural
	foreach y in $pro_outcomes {
		areg z_`y' i.noncoeth#i.int_coeth_leader  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4, abs(region) vce(robust)
		qui: margins, dydx(noncoeth) by(int_coeth_leader) noestimcheck post
		post `eleadercoeth' ("Procedural") ("`y'") ("FE4") ("Pooled") (0) (_b[1.noncoeth:0.int_coeth_leader]) (_se[1.noncoeth:0.int_coeth_leader]) (e(N)) (e(df_r))  
		post `eleadercoeth' ("Procedural") ("`y'") ("FE4") ("Pooled") (1) (_b[1.noncoeth:1.int_coeth_leader]) (_se[1.noncoeth:1.int_coeth_leader]) (e(N)) (e(df_r)) 
	}

	postclose `eleadercoeth' 
	use `elcoeth', clear

* calculate p values and confidence intervals
	gen t = b/se
	gen p= 2*ttail(df, abs(t))
	gen sig="*" if p<0.1 & p~=.
		replace sig="**" if p<0.05 & p~=.
		replace sig="***" if p<0.01 & p~=.
	gen min95=b - invttail(df,0.025)*se
	gen max95=b + invttail(df,0.025)*se

* merge in outcome labels
	gen order=_n
	gsort - sample + order
	replace order=_n
	
	merge m:1 outcome using "data/outcome_labels.dta"
	drop _merge
	order outcome specification sample label shortlab
	sort order
	drop order

* save results for Table A7: Impact of a Non-Coethnic Interviewer when Interviewer is Coethnic with Head of State
	export delimited using "output/e_leadercoeth.csv", replace

* generate graph
	gen id=_n
	replace id=id*-1
	sort id
	sencode shortlab, gen(y)
	replace y=y + 0.25 if e_leadercoeth==1

	* FIGURE 7b. Impacts of Non-Coethnic Interviewers ... When Interviewer is Coethnic with Head of State
	twoway (rspike min95 max95 y if e_leadercoeth==0 & type=="Political", hor lc(black) lw(thin)) ///
		(scatter y b if e_leadercoeth==0 & type=="Political", msize(small) ms(S) mc(white) mlc(black)) ///
		(rspike min95 max95 y if e_leadercoeth==1 & type=="Political", hor lc(black) lw(thin)) ///
		(scatter y b if e_leadercoeth==1 & type=="Political", msize(small) ms(S) mfc(black) mlc(black)) ///
		, ///
		legend(order(2 "Interviewer NOT Coethnic with Leader" 4 "Interviewer Coethnic with Leader") ///
		size (vsmall) row(3) region(lw(none) fc(none)) ring(1) pos(7) ) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#11, angle(horizontal) valuelabel labs(2.2) nogrid) ///
		xlabel(#6, labs(2.2)) ///
		xline(0, lpattern(shortdash)) ///
		xscale(r(-0.15 0.15)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(2.2)) ytitle("") ///
		graphregion(margin(l=50 b=5))
		graph export "output/e_leadercoeth.pdf", replace



*******************************************************************************

* ROBUSTNESS: interviewers with obvious ethnicity

	use "data/AFPR_final.dta", clear

* create temp files for output, graphing
	set more off
	tempfile obvs
	tempname obvious
	postfile `obvious' str30 type str30 outcome str30 specification str30 sample str30 subsample b se n df using `obvs', replace				   

* models

	* ethnic
	foreach y in $eth_outcomes {
		reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 if easy==1, vce(robust)
		post `obvious' ("Ethnic") ("`y'") ("FE4") ("Pooled") ("Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 $fe4 if easy==0, vce(robust)
		post `obvious' ("Ethnic") ("`y'") ("FE4") ("Pooled") ("Not Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r))
	}

	* political
	foreach y in $pol_outcomes {
		reg z_`y' noncoeth  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 if easy==1, vce(robust)
		post `obvious' ("Political") ("`y'") ("FE4") ("Pooled") ("Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		reg z_`y' noncoeth  age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 $fe4 if easy==0, vce(robust)
		post `obvious' ("Political") ("`y'") ("FE4") ("Pooled") ("Not Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}

	* individual ses
	foreach y in $stat_outcomes {
		reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4  if easy==1, vce(robust)
		post `obvious' ("SES") ("`y'") ("FE4") ("Pooled") ("Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 $fe4  if easy==0, vce(robust)
		post `obvious' ("SES") ("`y'") ("FE4") ("Pooled") ("Not Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}

	* procedural
	foreach y in $pro_outcomes {
		reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4  if easy==1, vce(robust)
		post `obvious' ("Procedural") ("`y'") ("FE4") ("Pooled") ("Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		reg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 $fe4  if easy==0, vce(robust)
		post `obvious' ("Procedural") ("`y'") ("FE4") ("Pooled") ("Not Obvious") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}

	postclose `obvious' 
	use `obvs', clear

* calculate p values and confidence intervals
	gen t = b/se
	gen p= 2*ttail(df, abs(t))
	gen sig="*" if p<0.1 & p~=.
		replace sig="**" if p<0.05 & p~=.
		replace sig="***" if p<0.01 & p~=.
	gen min95=b - invttail(df,0.025)*se
	gen max95=b + invttail(df,0.025)*se

* merge in outcome labels
	gen order=_n
	gsort - sample + order
	replace order=_n
	
	merge m:1 outcome using "data/outcome_labels.dta"
	drop _merge
	order outcome specification sample label shortlab
	sort order
	drop order

* save results
	export delimited using "output/obvious.csv", replace

* generate graph

	gen id=_n
	replace id=id*-1
	sort id
	sencode shortlab, gen(y)
	
	* FIGURE A1: Impacts of Non-Coethnic Interviewers on Survey Responses, Easy to Identify Interviewers Only
	twoway (rspike min95 max95 y if subsample=="Obvious", hor lc(black) lw(thin)) ///
		(scatter y b if subsample=="Obvious", msize(small) ms(O) mc(black) mlc(black)) ///
		, ///
		legend(order(2 "Interviewer Ethnicity Easy to Determine") ///
		size (vsmall) row(2) region(lw(none) fc(none)) ring(1) pos(7) ) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#31, angle(horizontal) valuelabel labs(2.2) nogrid) ///
		xlabel(#6, labs(2.2)) ///
		xsize(4) ysize(8)  ///
		xline(0, lpattern(shortdash)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(2.2)) ytitle("") ///
		graphregion(margin(l=50 b=5))
		graph export "output/obvious.pdf", replace



*******************************************************************************

* ROBUSTNESS: Enumerator Fixed Effects

	use "data/AFPR_final.dta", clear

* create temp files for output, graphing
	set more off
	tempfile enumfe
	tempname ife
	postfile `ife' str30 type str30 outcome str30 specification str30 sample b se n df using `enumfe', replace				   

* models

	* ethnic
	foreach y in $eth_outcomes {
		areg z_`y' noncoeth, abs(enumid) vce(robust)
		post `ife' ("Ethnic") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $regions , abs(enumid)  vce(robust)
		post `ife' ("Ethnic") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3 , abs(enumid) vce(robust)
		post `ife' ("Ethnic") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , abs(enumid) vce(robust)
		post `ife' ("Ethnic") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}


	* political
	foreach y in $pol_outcomes {
		areg z_`y' noncoeth $countries, abs(enumid) vce(robust)
		post `ife' ("Political") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $regions , abs(enumid)  vce(robust)
		post `ife' ("Political") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3 , abs(enumid) vce(robust)
		post `ife' ("Political") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , abs(enumid) vce(robust)
		post `ife' ("Political") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}

	* individual ses
	foreach y in $stat_outcomes {
		areg z_`y' noncoeth $countries, abs(enumid) vce(robust)
		post `ife' ("SES") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $regions , abs(enumid)  vce(robust)
		post `ife' ("SES") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3 , abs(enumid) vce(robust)
		post `ife' ("SES") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , abs(enumid) vce(robust)
		post `ife' ("SES") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}

	* procedural
	foreach y in $pro_outcomes {
		areg z_`y' noncoeth $countries, abs(enumid) vce(robust)
		post `ife' ("Procedural") ("`y'") ("Bivariate") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $regions , abs(enumid)  vce(robust)
		post `ife' ("Procedural") ("`y'") ("FE2") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe3 , abs(enumid) vce(robust)
		post `ife' ("Procedural") ("`y'") ("FE3") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
		areg z_`y' noncoeth age gender edu urban minority Round4 ethsize ethsize2 enum_ethsize enum_ethsize2 inhomelang $fe4 , abs(enumid) vce(robust)
		post `ife' ("Procedural") ("`y'") ("FE4") ("Pooled") (_b[noncoeth]) (_se[noncoeth]) (e(N)) (e(df_r)) 
	}


	postclose `ife' 
	use `enumfe', clear

	replace specification="1" if specification=="Bivariate"
	replace specification="2" if specification=="FE2"
	replace specification="3" if specification=="FE3"
	replace specification="4" if specification=="FE4"

* calculate p values
	gen t = b/se
	gen p= 2*ttail(df, abs(t))
	gen sig="*" if p<0.1 & p~=.
		replace sig="**" if p<0.05 & p~=.
		replace sig="***" if p<0.01 & p~=.
	gen min95=b - invttail(df,0.025)*se
	gen max95=b + invttail(df,0.025)*se
	
* merge in outcome labels
	gen order=_n
	merge m:1 outcome using "data/outcome_labels.dta"
	drop _merge
	order outcome type specification sample label shortlab
	sort order
	drop order

* save results
	export delimited using "output/int_fixedeffects.csv", replace

* generate graph *
	gen id=_n
	replace id=id*-1
	sort id
	sencode shortlab, gen(y)

	* FIGURE A2: Impacts of Non-Coethnic Interviewers on Survey Responses, Interviewer Fixed Effects
	twoway (rspike min95 max95 y if specification=="4", hor lc(black) lw(thin)) ///
		(scatter y b if specification=="4", msize(small) ms(O) mc(black) mlc(black)) ///
		, ///
		legend(order(2 "Includes Interviewer Fixed-Effects") ///
		size (vsmall) row(2) region(lw(none) fc(none)) ring(1) pos(7) ) ///
		scheme(s2mono) graphregion(fcolor(white)) ///
		ylabel(#31, angle(horizontal) valuelabel labs(2.2) nogrid) ///
		xlabel(#6, labs(2.2)) ///
		xsize(4) ysize(8)  ///
		xline(0, lpattern(shortdash)) ///
		xtitle("Estimated Effect (in SDs) of Non-Coethnic Interviewer" "95% Confidence Intervals", size(2.2)) ytitle("") ///
		graphregion(margin(l=50 b=5))
		graph export "output/intfe.pdf", replace

			
******************************************************************************

* ROBUSTNESS: Additional

	use "data/AFPR_final.dta", clear
	set more off

* Don't Know/Refuse to Answer/Refuse to Participate by Noncoethnicity
	ttest totaldk, by(noncoeth) // prop. of questions DK or RTA
	ttest prevref, by(noncoeth) // number of previous refusals for each respondent

* total number of refusals and % non-coeth interviews (across enumerators)
	summ ratio if enumtag==1
	summ totalnoncoeth if enumtag==1
	xtile q_totalnoncoeth=totalnoncoeth if enumtag==1, nq(5) 
	tab q_totalnoncoeth, summ(ratio) 
	anova ratio q_totalnoncoeth

* Regional Minorities and Non-Coethnic interviews
	ttest noncoeth, by(minority) // prop. of questions DK or RTA

* Noncoethnic interviewers and language of interview
	ttest inhomelang, by(noncoeth) // prop. of interviews in home language by shared interviewer-respondent coethnicity 

* Noncoethnic interviewers and level of enumerator education
	summ enum_urban if enumtag==1
	ttest enum_urban, by(noncoeth)
	summ enum_postgrad if enumtag==1
	ttest enum_postgrad, by(noncoeth)


******************************************************************************

* TABLE A1: Interviewer/Respondent Dyads by Ethnic Group in South Africa  	

* main table contents
	tab enumeth tribe if safrica==1 

* Percent of interviews conducted by a coethnic interviewer
	tab tribe if safrica==1, summ(coeth) 

* probability of coethnic dyad w/random assignment in this interviewer/respondent pool:
	bys country: egen csample=count(noncoeth)
	bys country tribe: egen csample_resp=count(noncoeth)
	bys country enumeth: egen csample_enum=count(noncoeth)
	gen expected=(csample_resp/csample)*(csample_enum/csample) if noncoeth==0
	tab tribe if safrica==1, summ(expected)


******************************************************************************

* TABLE A9: Replication of Nunn and Wantchekon (2011)

/* Nunn & Wantchekon table 1: coefficient and standard error of slave exports
on trust in neithbors */

	use "data/Nunn_Wantchekon_AER_2011.dta", clear
	gen round=3 // Nunn and Wantchekon AB data is 2005 only, which is R3

	merge 1:m respno round using "data/AFPR_final.dta", keepusing(noncoeth)
	drop if _merge~=3 // drop unmatched

	local baseline_controls "age age2 male urban_dum i.education i.occupation i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.isocode"

	*** Slave exports only ***
	xi: reg trust_neighbors exports `baseline_controls', cluster(murdock_name)
	xi: reg trust_neighbors exports noncoeth `baseline_controls', cluster(murdock_name)

	*** Slave exports/land area ***
	xi: reg trust_neighbors export_area `baseline_controls', cluster(murdock_name)
	xi: reg trust_neighbors export_area noncoeth `baseline_controls', cluster(murdock_name)

	*** Slave exports/historic pop ***
	xi: reg trust_neighbors export_pop `baseline_controls', cluster(murdock_name)
	xi: reg trust_neighbors export_pop noncoeth `baseline_controls', cluster(murdock_name)

	*** ln slave exports ***
	xi: reg trust_neighbors ln_exports `baseline_controls', cluster(murdock_name)
	xi: reg trust_neighbors ln_exports noncoeth `baseline_controls', cluster(murdock_name)

	*** ln slave exports/land area ***
	xi: reg trust_neighbors ln_export_area `baseline_controls', cluster(murdock_name)
	xi: reg trust_neighbors ln_export_area noncoeth `baseline_controls', cluster(murdock_name)

	*** ln slave exports/historic pop ***
	xi: reg trust_neighbors ln_export_pop `baseline_controls', cluster(murdock_name)
	xi: reg trust_neighbors ln_export_pop noncoeth `baseline_controls', cluster(murdock_name)

******************************************************************************

* TABLE A10: Replication of Lieberman and McClendon (2013)

/* McClendon Lieberman Table 1a: P-values of Chi-square Statistics from Logistic Models, 
estimating the probability of a respondent identifying a given issue as her first priority 
as a function of ethnic group dummy variables */

	clear all
	set more off

	use "data/McClendonLieberman_EthnPref_variables.dta", clear
	gen round=3 // study uses only round 3 of AB
	sort country respno round
	drop if respno==""
	merge 1:m respno round using "data/AFPR_final.dta", keepusing(noncoeth)
	drop if _merge~=3

	**benin
	logit farmingany noncoeth i.subjgroup if country==1
	logit foodany noncoeth i.subjgroup if country==1 
	logit electricany noncoeth i.subjgroup if country==1 
	logit unempany noncoeth i.subjgroup if country==1 
	logit roadsany noncoeth i.subjgroup if country==1 
	logit educany noncoeth i.subjgroup if country==1 
	logit waterany noncoeth i.subjgroup if country==1 
	logit healthany noncoeth i.subjgroup if country==1 
	**ghana
	logit educany noncoeth i.subjgroup if country==4 
	logit unempany noncoeth i.subjgroup if country==4 
	logit healthany noncoeth i.subjgroup if country==4 
	logit waterany noncoeth i.subjgroup if country==4 
	logit roadsany noncoeth i.subjgroup if country==4 
	logit povertyany noncoeth i.subjgroup if country==4 
	logit electricany noncoeth i.subjgroup if country==4 
	logit wagesany noncoeth i.subjgroup if country==4 
	**kenya
	logit unempany noncoeth i.subjgroup if country==5 
	logit healthany noncoeth i.subjgroup if country==5 
	logit educany noncoeth i.subjgroup if country==5 
	logit povertyany noncoeth i.subjgroup if country==5 
	logit waterany noncoeth i.subjgroup if country==5 
	logit crimeany noncoeth i.subjgroup if country==5
	logit roadsany noncoeth i.subjgroup if country==5  
	logit foodany noncoeth i.subjgroup if country==5 
	**malawi
	logit foodany noncoeth ib263.subjgroup if country == 8 
	logit waterany noncoeth ib263.subjgroup if country == 8 
	logit farmingany noncoeth ib263.subjgroup if country == 8 
	logit healthany noncoeth ib263.subjgroup if country == 8 
	logit educany noncoeth ib263.subjgroup if country == 8 
	logit povertyany noncoeth ib263.subjgroup if country == 8 
	logit roadsany noncoeth ib263.subjgroup if country == 8 
	logit unempany noncoeth ib263.subjgroup if country == 8 
	**mali
	logit foodany noncoeth i.subjgroup if country == 9
	logit povertyany noncoeth i.subjgroup if country == 9
	logit waterany noncoeth i.subjgroup if country == 9
	logit healthany noncoeth i.subjgroup if country == 9
	logit educany noncoeth i.subjgroup if country == 9
	logit farmingany noncoeth i.subjgroup if country == 9
	logit unempany noncoeth i.subjgroup if country == 9
	logit roadsany noncoeth i.subjgroup if country == 9
	**namibia
	logit unempany noncoeth i.subjgroup if country == 11 
	logit educany noncoeth i.subjgroup if country == 11 
	logit aidsany noncoeth i.subjgroup if country == 11 
	logit corruptany noncoeth i.subjgroup if country == 11 
	logit crimeany noncoeth i.subjgroup if country == 11 
	logit povertyany noncoeth i.subjgroup if country == 11 
	logit waterany noncoeth i.subjgroup if country == 11 
	logit wagesany noncoeth i.subjgroup if country == 11 
	**nigeria
	logit unempany noncoeth i.subjgroup if country==12 
	logit povertyany noncoeth i.subjgroup if country==12
	logit foodany noncoeth i.subjgroup if country==12 
	logit educany noncoeth i.subjgroup if country==12 
	logit corruptany noncoeth i.subjgroup if country==12 
	logit electricany noncoeth i.subjgroup if country==12 
	logit roadsany noncoeth i.subjgroup if country==12 
	logit transportany noncoeth i.subjgroup if country==12 
	**senegal
	logit healthany  noncoeth i.subjgroup if country == 13
	logit foodany  noncoeth i.subjgroup if country == 13 
	logit unempany  noncoeth i.subjgroup if country == 13 
	logit farmingany  noncoeth i.subjgroup if country == 13 
	logit educany  noncoeth i.subjgroup if country == 13 
	logit waterany  noncoeth i.subjgroup if country == 13 
	logit electricany  noncoeth i.subjgroup if country == 13 
	logit roadsany  noncoeth i.subjgroup if country == 13
	**south africa
	logit unempany noncoeth ib109.subjgroup if country==14  
	logit housingany noncoeth ib109.subjgroup if country==14
	logit povertyany noncoeth ib109.subjgroup if country==14 
	logit aidsany noncoeth ib109.subjgroup if country==14 
	logit crimeany noncoeth ib109.subjgroup if country==14 
	logit corruptany noncoeth ib109.subjgroup if country==14 
	logit roadsany noncoeth ib109.subjgroup if country==14 
	logit waterany noncoeth ib109.subjgroup if country==14 
	**uganda
	logit povertyany noncoeth ib417.subjgroup if country == 16 
	logit educany noncoeth ib417.subjgroup if country == 16
	logit healthany noncoeth ib417.subjgroup if country == 16 
	logit unempany noncoeth ib417.subjgroup if country == 16 
	logit waterany noncoeth ib417.subjgroup if country == 16 
	logit foodany noncoeth ib417.subjgroup if country == 16  
	logit roadsany noncoeth ib417.subjgroup if country == 16
	logit civilwarany noncoeth ib417.subjgroup if country == 16  
	**zambia
	logit unempany noncoeth i.subjgroup if country == 17 
	logit povertyany noncoeth i.subjgroup if country == 17 
	logit educany noncoeth i.subjgroup if country == 17 
	logit farmingany noncoeth i.subjgroup if country == 17 
	logit roadsany noncoeth i.subjgroup if country == 17 
	logit healthany noncoeth i.subjgroup if country == 17
	logit waterany noncoeth i.subjgroup if country == 17 
	logit wagesany noncoeth i.subjgroup if country == 17 

******************************************************************************



