
*******************************************************************************

* GENERAL INFO
	* Project: Who's Asking? Interviewer Coethnicity Effects in African Survey Data
	* Created: by Claire Adida, Karen Ferree, Dan Posner, and Amanda Robinson
	* Updated: 28 Feb 16 by Julia Clark

* DO FILE INFO
	* This .do file merges and cleans data from Afrobarometer Rounds 3 & 4
	* Required .do files: clean_3.do, clean_4.do, q79label.do
	* Inputs: ABR3Data.dta, ABR4Data.dta, AB3_regional_concordance.dta, AB4_regional_concordance.dta
	* Outputs: AFPR_final.dta

	
*******************************************************************************

* DIRECTORY: uncomment if using separately from AFPR_analysis.do

	*clear all
	*set more off
	*capture cd "~/Dropbox/AFPR_replication_files"
	
* PACKAGES
	
	*ssc install labutil
	*ssc install distinct
	*ssc install center

*******************************************************************************

* DATA MERGE	

	run "code/clean_3.do" // clean and merge R3 data
	tempfile r3
	save `r3'

	run "code/clean_4.do" // clean and merge R4 data
	tempfile r4
	save `r4'

	append using `r3' // append R3 and R4 data

*******************************************************************************

* CLEANING AND VARIABLE CREATION	

* Drop country's missing enumerator data: botswana, cape verde, lesotho, liberia, madagascar, tanzania
	drop if country==.
	drop if country==2 | country==4 | country==7 | country==8 | country==9 | country==17

* AB Round Dummy
	gen Round4=1 if round==4
	replace Round4=0 if Round4==.
	replace Round4=. if round==.
		
* Certainty variable
	replace certain=0 if certain==1
	replace certain=1 if certain==2

* Recognizability interaction variable
	gen easy=1 if obvious==2
	replace easy=0 if obvious==1

* Get R3 and R4 concordance for regions
	gen r3region=region if round==3
	merge m:m r3region using "data/AB3_regional_concordance.dta" 
	drop if _merge==2
	drop _merge

	gen r4region=region if round==4 
	merge m:m r4region using "data/AB4_regional_concordance.dta" 
	drop if _merge==2
	drop _merge

	gen newregion=region_name3 if round==3
	replace newregion=region_name4 if round==4
	rename region oldregion

	egen country_region=concat(country newregion)
	encode country_region, gen(region)

	labmask region if round==3, values(region_name3)
	labmask region if round==4, values(region_name4)

* calculate ethnic group sizes using weights assigned in AB3/AB4 at ind level

	* calculate ethnic group size using AB3
	bys country tribe: egen num=total(withinwt) if round==3
	bys country: egen pop=total(withinwt) if round==3
	gen ethsize=num/pop

	*fill in R3 ethnic group size for R4 observations
	sort country tribe round
	bys country tribe: replace ethsize=ethsize[_n-1] if ethsize==.

	*calculate ethnic group size using AB4 for countries only in R4
	bys country tribe: egen num4=total(withinwt) if new4==1
	bys country: egen pop4=total(withinwt) if new4==1
		replace num=num4 if new4==1
		replace pop=pop4 if new4==1
		replace ethsize=num4/pop4 if new4==1
		drop num4 pop4 
	gen ethsize2=ethsize^2
	
	tempfile ethnicsize
	save `ethnicsize'
	
	*create temp dataset of ethsize by tribe
	collapse ethsize, by(tribe)
	rename tribe enumeth
	rename ethsize enum_ethsize
	drop if enumeth==.
	
	tempfile enum_ethsize
	save `enum_ethsize'
	
	* transfer ethsize to enum
	use `ethnicsize', replace
	merge m:1 enumeth using `enum_ethsize'
	gen enum_ethsize2=enum_ethsize^2
	drop if _merge==2

* Regional minority status
	bys region: egen plurality=mode(tribe), min
	gen minority=(plurality~=tribe) if plurality~=. & tribe~=.
	ttest noncoeth, by(minority) // noncoeth MUCH more likley for regional minority

* generate dummies for fixed effects
	tab tribe, gen(tribe)
	tab region, gen(region)
	tab enumeth, gen(enumtribe)
	tab country, gen(country)

* code race variables for S. Africa
	recode tribe (101/109=1)(100 110 113=2)(111=3)(112=4) if safrica==1, gen(race)
	lab def race 1 "Black African" 2 "White African" 4 "Indian" 3 "Coloured"
	lab val race race

	recode enumeth (101/109=1)(100 110 113=2)(111=3)(112=4) if safrica==1, gen(enum_race)
	gen enum_african=(enum_race==1) if enum_race~=.
	gen enum_white=(enum_race==2) if enum_race~=.
	gen enum_indian=(enum_race==4) if enum_race~=.
	gen enum_coloured=(enum_race==3) if enum_race~=.

* politically relevant ethnic groups variable (pr_dyad=1 only if non-coeth=1)
	gen pr_noncoeth=(noncoeth==1 & pr_dyad==1)
	gen npr_noncoeth=(noncoeth==1 & pr_dyad==0)

	* alternative coding where coeth dyads can also be politically relevant
	recode pr_dyad (0=1) if noncoeth==0 & resp_prgroup==1, gen(pr_dyad2)

* calculate number of interviews per enumerator
	egen intnum=count(age) if enumeth~=., by(enumid)
	egen inttag = tag(enumid) if enumeth~=.
	replace inttag=0 if intnum==0

* "cosmipolitanness" and education of enumerator	
	recode q113 (2=1)(1=0)(-1=.), gen(enum_urban)
	gen enum_edu=q115
	recode enum_edu (3/5=0)(6/9=1)(-1=.), gen(enum_postgrad)
	
* global outcome lists
	global eth_outcomes idrank patronage etrust netrust ecconditions_group polinfluence_group treatedunfairly_group 
	global pol_outcomes demosupp performance bribe1 ec_conditions_ctry trust_rulingparty trust_opposition  gov_manage_economy voted pubaffairs meeting knows_MP 
	global stat_outcomes ec_conditions_self notenoughfood noincome nocleanwater crime aids
	global pro_outcomes hostile uncooperative impatient suspicious
	global outcomes $eth_outcomes $pol_outcomes $stat_outcomes $pro_outcomes 

* standardize outcomes for pooled sample and by country
	foreach o in $outcomes {
		center `o', standardize prefix(z_)
	}


	foreach o in $outcomes {
		bys country: center `o', standardize prefix(co_)
	}

* create unique dyad ids
	gen first = cond(enumeth < tribe, enumeth, tribe)
	gen second = cond(enumeth < tribe, tribe, enumeth)
	egen udyad = group(first second) if tribe~=. & enumeth~=.
	bys udyad: egen udyad_count=count(noncoeth)
	lab val first q79
	lab val second q79

	decode first, gen(dyad1)
	decode second, gen(dyad2)
	drop first second
	replace dyad1=proper(dyad1)
	replace dyad2=proper(dyad2)
	split dyad1, p(/)
	replace dyad1=dyad11
	drop dyad12 dyad13
	split dyad2, p(/)
	replace dyad2=dyad21
	drop dyad22 dyad23

	egen udyad_name=concat(dyad1 dyad2) if tribe~=. & enumeth~=., punct(-)
	labmask udyad, values(udyad_name)


*******************************************************************************

*
	la var round "AB round"
	la var idrank "National identification vs in terms of ethnic group (AB3-q82, AB4-q83)"
	la var patronage "Belief that politicians should help home community (AB3-q21, AB4-q17)"
	la var etrust "How much trust coethnic (AB3-q84c)"
	la var netrust "How much trust noncoethnic relative to coethnic (AB3-q84d)"
	la var ecconditions_group "Ethnic group's comparative economic conditions (AB3-q80a, AB4-q80)"
	la var polinfluence_group "Ethnic group's comparative political influence (AB3-q80b, AB4-q81)"
	la var treatedunfairly_group "Ethnic group is treated unfairly by government (AB3-q81, AB4-q82)"	
	la var demosupp "Preference for democracy over other types of government (AB3-q37, AB4-q30)"
	la var performance "Approval of president's performance (AB3-q68a, AB4-q70a)"
	la var bribe1 "Exposure to vote buying (AB3-q57f)"
	la var ec_conditions_ctry "Assessment of country's present economic conditions(AB3/4-q4a)"
	la var trust_rulingparty "Trust in ruling party (AB3-q55e, AB4-q49e)"
	la var trust_opposition "Trust in opposition parties (AB3-q55f, AB4-q49f)"
	la var gov_manage_economy "Assessment of government's handling of economy (AB3-q65a, AB4-q57a)"
	la var voted "Voted in last national election (AB3-q30, AB4-q23d)" 
	la var pubaffairs "Interest in public affairs (AB3-q16, AB4-q13)"
	la var meeting "Attendance at community meetings (AB3-q31a, AB4-q23a)"
	la var knows_MP "Knows MP's name (AB3-q43a2, AB4-q41a2)"
	la var ec_conditions_self "Assessment of own present living conditions (AB3/4-q4b)"
	la var notenoughfood "Has gone without enough food (AB3/4-q8a)"
	la var noincome "Has gone without cash income (AB3/4-q8e)"
	la var nocleanwater "Has gone without enough clean water (AB3/4-q8b)"
	la var crime "Has feared crime in own home (AB3/4-q9a)"
	la var aids "Knows a friend/relative who died of AIDS (AB3-q97, AB4-q95)"
	la var hostile "Respondent was hostile (AB3/4-q108a)"
	la var uncooperative "Respondent was uncooperative (AB3/4-q108c)"
	la var impatient "Respondent was impatient (AB3/4-q108d)"
	la var suspicious "Respondent was suspicious (AB3/4-q108e)"
	la var inhomelang "Interview conducted in respondent's home language (AB3/4-q3==AB3/4-q103)"
	la var coeth "Coethnic Interviewer (tribe==enumeth)"
	la var noncoeth "Non-Coethnic Interviewer (tribe~=enumeth)"
	la var gender "Male (AB3-currint, AB4-thisint)"
	la var age "Age (AB3/4-q1)"
	la var edu "Education (AB3-q90, AB4-q89)"
	la var urban "Urban (AB3/4-urbrur)"
	la var Round4 "Afrobarometer Round 4"
	la var minority "Regional minority--not member of region's most prevalent ethnicity (AB3/4-q79)"
	la var ethsize "Ethnic group size as a proportion of population (using AB3/4-withinwt)"
	la var ethsize2 "Ethnic group size, squared (ethsize^2)"
	la var enum_ethsize "Interviewer's ethnic group size (total enumeth)"
	la var enum_ethsize2 "Interviewer's ethnic group size, squared (enum_ethsize^2)"
	la var region "Province or region (AB3/4-region)"
	la var tribe "Tribe or Ethnic Group (AB3/4-q79)"
	la var enum_african "Interviewer is Black African in South Africa (AB3/4-q79)"
	la var enum_white "Interviewer is White African in South Africa (AB3/4-q79)"
	la var enum_coloured "Interviewer is Coloured in South Africa (AB3/4-q79)"
	la var enum_indian "Interviewer is Indian in South Africa (AB3/4-q79)"
	la var race "Ethncity in South Africa (AB3/4-q79)"
	la var dyad "Enumerator's ethnicity and respondant's tribe (enumeth & tribe)"
	la var pr_noncoeth "Non-coethnic interviewer in politically relevant dyad (dyad data from Posner 2004)"
	la var npr_noncoeth "Non-coethnic interviewer in non-politically relevant dyad (dyad data from Posner 2004)"
	la var coeth_leader "Respondant is coethnic with national leader (coded by authors)"
	la var int_coeth_leader "Interviewer is coethnic with national leader (coded by authors)"
	la var enumid "Enumerator ID (AB3/4-q110)"
	la var enumtag "Enumerator round and ID (round & enumid)"
	la var enumeth "Enumerator Ethnicity (coded by authors)"
	la var certain "AB country directors' degree of certainty on interviewer's ethnicity (coded by authors)"
	la var obvious "Interviewer’s ethnicity is obvious (coded by authors)"
	la var easy "Ease of observing interviewer’s ethnicity (coded by authors)"
	la var totaldk "Total don't know/refuse to answer responses for AB questions used in analysis"
	la var prevref "Refuse to answers for enumerator's previous interviews (AB3-hholdse*, AB4-nocall_*)"
	la var ratio "Ratio of refusals to interviews for each enumerator"
	la var totalnoncoeth "Average proporation of interviews that are noncoethnic for each interviewer"
	la var enum_urban "Enumerator is urban (AB3/4-q113)"
	la var enum_postgrad "Enumerator has postgraduate education (AB3/4 q115)"

	
*******************************************************************************

* SAVE FINAL DATA

	keep respno round idrank patronage etrust netrust ecconditions_group polinfluence_group treatedunfairly_group ///
		demosupp performance bribe1 ec_conditions_ctry trust_rulingparty trust_opposition gov_manage_economy voted pubaffairs meeting knows_MP ///
		ec_conditions_self notenoughfood noincome nocleanwater crime aids ///
		hostile uncooperative impatient suspicious ///
		inhomelang coeth noncoeth gender age edu urban Round4 minority ethsize ethsize2 enum_ethsize enum_ethsize2 country region tribe ///
		enum_* race safrica ///
		dyad pr_noncoeth npr_noncoeth ///
		coeth_leader int_coeth_leader ///
		enumid enumtag enumeth certain obvious easy ///
		totaldk prevref ratio totalnoncoeth ///
		region* country* tribe* enumtribe* ///
		co_* z_* ///
	
	drop enum_edu country_region region_name3 region_name4
		
	saveold "data/AFPR_final", replace

*******************************************************************************

	
	
