
*******************************************************************************

* GENERAL INFO
	* Project: Who’s Asking? Interviewer Coethnicity Effects in African Survey Data
	* Created: by Claire Adida, Karen Ferree, Dan Posner, and Amanda Robinson
	* Updated: 28 Feb 16 by Julia Clark

* DO FILE INFO
	* Auxilary .do file for AFPR_clean.do that cleans ABR3 data and merges in ethnicity data
	* Inputs: ABR3Data.dta, AB3_Nigeria_enumcorrection.dta, AB3_Safrica_enumcorrection.dta, AB_enumerators.dta, pol_rel_dyads.dta, leader_ethnicity.dta

*******************************************************************************

* LOAD AND CLEAN DATA

	use "data/ABR3Data.dta"
	
* generate AB round variable
	gen round=3

* drop zimbabwe, missing ethnicity data	
	drop if country==18 	

* create country dummies
	* note: no ABR3 in burkina faso & liberia
	tab country, gen(dummy)
	rename dummy1 benin
	rename dummy2 botswana
	rename dummy3 capeverde
	rename dummy4 ghana
	rename dummy5 kenya
	rename dummy6 lesotho
	rename dummy7 madagascar
	rename dummy8 malawi
	rename dummy9 mali
	rename dummy10 mozambique
	rename dummy11 namibia
	rename dummy12 nigeria
	rename dummy13 senegal
	rename dummy14 safrica
	rename dummy15 tanzania
	rename dummy16 uganda
	rename dummy17 zambia

* recode country codes to match R4
	label drop country
	recode country (3=4)(4=5)(5=6)(6=7)(7=9)(8=10)(9=11)(10=12)(11=13)(12=14)(13=15)(14=16)(15=17)(16=18)(17=19)(18=20)

*******************************************************************************

* TREATMENT VARIABLES	
	
* language 
	recode q3 q103 q114 (-1 995 998 999=.)	
	rename q3 resplang // Respondent's Home Langauge
	rename q114 intlang // Interviewer's Home Language
	rename q103 langused // Language of Interview

* tribe
	recode q79 (995 997 998 999 -1 990 = .)
	gen tribe=q79 // tribe or ethnic group
	rename q79 q79_3 // keep original AB coding of tribe in "q79_3"

* respondent and interviewer speak same home language
	gen colang=1 if resplang==intlang // colanguage Interviewer
	replace colang=0 if resplang~=intlang
	lab def colang 0 "No" 1 "Yes"
	lab val colang colang
	
* merge in Nigeria and South Africa corrected enumerator ids
	merge respno using "data/AB3_Nigeria_enumcorrection.dta", unique sort
	replace q110=intvno if nigeria==1
	drop _merge intvno
	
	merge respno using "data/AB3_Safrica_enumcorrection.dta", unique sort
	replace q110=intvno if safrica==1
	drop _merge intvno
	
* merge in enumerator ethnicity data
	sort round q110
	merge round q110 using "data/AB_enumerators.dta", uniqusing
	drop if country==. // drop the 657 enumerators from Round 4

	recode enumeth (999 995=.) // enumerator ethnicity
	lab val enumeth q79
	drop _merge

* coethnicity/language variables
	gen coeth=1 if tribe==enumeth & tribe~=. & enumeth~=. // coethnic interviewer
	recode coeth (.=0) if tribe~=enumeth & tribe~=. & enumeth~=.
	lab val coeth colang
	recode coeth (0=1)(1=0), gen(noncoeth) // non-coethnic interviewer
	lab val noncoeth colang

	gen inhomelang=1 if resplang==langused // interview conducted in respondent's home language
	replace inhomelang=0 if resplang~=langused

* create round-specific enum ids
	egen enumid=concat(round q110) // "Enumerator ID"	
	
* merge in political relevance for resp, enum, and dyad
	lab val tribe q79
	egen dyad=concat(enumeth tribe) if enumeth~=. & tribe~=., punct(-)
	sort dyad
	merge dyad using "data/pol_rel_dyads.dta", uniqusing
	drop _merge

	
*******************************************************************************

* DEPENDENT VARIABLES	

* national versus ethnic identity
	gen idrank=q82 // National identification vs in terms of ethnic group
	recode idrank (9 98 -1 7 = .)
	recode idrank (.=5) if tribe==990
	*recode idrank (.=1) if tribe==990
	recode idrank (1=0) (2=1) (3=2) (4=3) (5=4)
	la def idrank 0 "ethnic only" 1 "ethnic over national" 2 "equal" 3 "national over ethnic" 4 "national only", modify

* trust in coethnics and noncoethnics
	gen etrust=q84c // how much trust coethnic
	gen netrust=q84d // how much trust noncoethnic relative to coethnic
	recode etrust netrust (7 9 98 998 999 -1=.)

* politicians should help community
	gen patronage=q21 // belief that politicians should help home community
	recode patronage (5=.) (-1=.) (9=.) (98=.)
	recode patronage (1=2)(4=3)
	recode patronage (2=0)(3=1)
	la def patronage 0 "against patronage" 1 "support patronage"
	la val patronage patronage

* support for democracy
	gen demosupp=q37
	recode demosupp (9 98 998 999 -1=.)
	recode demosupp (1 2=0)
	recode demosupp (3=1)
	la def demosupp 0 "demo not always best or doesn't matter" 1 "democracy best"
	la val demosupp demosupp
	
* approve of incumbent's performance
	gen performance=1 if q68a==3 | q68a==4
	replace performance=0 if performance==.
	replace performance=. if q68a==-1 | q68a==9 | q68a==98
	la def performance 0 "Disapprove" 1 "Approve"
	la val performance performance
	tab performance, missing

* Pay bribe for election
	gen bribe1=q57f
	replace bribe1=0 if bribe1==7
	replace bribe1=. if bribe1==9 | bribe1==98 | bribe1==-1
	la def bribe 0 "Never" 1 "Once or twice" 2 "A few times" 3 "Often"
	la val bribe1 bribe
	tab bribe1, missing

* interest in public affairs
	gen pubaffairs=q16
	replace pubaffairs=. if pubaffairs==-1
	replace pubaffairs=. if pubaffairs==98
	replace pubaffairs=. if pubaffairs==9
	tab pubaffairs, missing

* community meeting
	gen meeting=q31a
	replace meeting=. if meeting==-1
	replace meeting=. if meeting==98
	replace meeting=. if meeting==9
	tab meeting, missing

* Factual knowledge of MP
	gen knows_MP = 0 if q43a2 < 3 | q43a2==9
	replace knows_MP = 1 if q43a2 == 3
	replace knows_MP = . if q43a2==-1 | q43a2==98
	lab def knows_MP 0 "does not know MP" 1 "knows MP"
	lab val knows_MP knows_MP
	tab knows_MP, missing

* Economic conditions of country
	gen ec_conditions_ctry = q4a
	replace ec_conditions_ctry = . if q4a==-1 | q4a==9 | q4a==98
	la def ec_conditions_ctry 1 "very bad" 2 "fairly bad" 3 "neither good nor bad" 4 "fairly good" 5 "very good"
	la val ec_conditions_ctry ec_conditions_ctry
	tab ec_conditions_ctry, missing

* Personal economic conditions
	gen ec_conditions_self = q4b
	replace ec_conditions_self = . if q4b==-1 | q4b==9 | q4b==98
	la def ec_conditions_self 1 "very bad" 2 "fairly bad" 3 "neither good nor bad" 4 "fairly good" 5 "very good"
	la val ec_conditions_self ec_conditions_self
	tab ec_conditions_self, missing

* Not enough food to eat
	gen notenoughfood = q8a
	replace notenoughfood = . if q8a==-1 | q8a==9 | q8a==98
	la def notenoughfood 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	la val notenoughfood notenoughfood
	tab notenoughfood, missing

* Trust ruling party
	gen trust_rulingparty = q55e
	replace trust_rulingparty =  . if q55e==-1 | q55e==9 | q55e==98
	la def trust_rulingparty 0 "not at all" 1 "just a little" 2 "somewhat" 3 "a lot"
	la val trust_rulingparty trust_rulingparty
	tab trust_rulingparty, missing

* Trust opposition parties
	gen trust_opposition = q55f
	replace trust_opposition =  . if q55f==-1 | q55f==9 | q55f==98
	la def trust_opposition 0 "not at all" 1 "just a little" 2 "somewhat" 3 "a lot"
	la val trust_opposition trust_opposition
	tab trust_opposition, missing

* How well is government managing economy
	gen gov_manage_economy = q65a
	replace gov_manage_economy = . if q65a==-1 | q65a==9 | q65a==98
	la def gov_manage_economy 1 "very badly" 2 "fairly badly" 3 "fairly well" 4 "very well"
	lab val gov_manage_economy gov_manage_economy 
	tab gov_manage_economy, missing

* Economic conditions of group versus other groups
	gen ecconditions_group = q80a
	replace ecconditions_group = . if q80a==-1 | q80a==7 | q80a==9 | q80a==98
	recode ecconditions_group (1=5)(2=4)(3=3)(5=1)(4=2)
	lab def ecconditions_group 5 "much better" 4 "better" 3 "same" 2 "worse" 1 "much worse"
	lab val ecconditions_group ecconditions_group
	tab ecconditions_group, missing

* Political influence of group versus other groups
	gen polinfluence_group = q80b
	replace polinfluence_group = . if q80b==-1 | q80b==7 | q80b==9 | q80b==98
	recode polinfluence_group (1=5)(2=4)(3=3)(5=1)(4=2)
	lab def polinfluence_group 5 "much better" 4 "better" 3 "same" 2 "worse" 1 "much worse"
	lab val polinfluence_group polinfluence_group
	tab polinfluence_group, missing

* Group treated unfairly by government
	gen treatedunfairly_group = q81
	replace treatedunfairly_group = . if q81==-1 | q81==7 | q81==9 | q81==98
	lab def treatedunfairly_group 0 "never" 1 "sometimes" 2 "often" 3 "always"
	lab val treatedunfairly_group treatedunfairly_group
	tab treatedunfairly_group, missing

* Friend/relative died of AIDS
	gen aids = q97
	replace aids =. if q97==-1 | q97==8 | q97==9
	lab def aids 0 "no" 1 "yes"
	lab val aids aids
	tab aids, missing

* Voted in last election
	gen voted = 1 if q30  == 1
	replace voted = 0 if voted == .
	replace voted = . if q30==-1 | q30==9 | q30==98
	lab def voted 0 "did not vote" 1 "voted"
	lab val voted voted
	tab voted, missing

* cash income
	gen noincome = q8e
	replace noincome = . if q8e == -1 | q8e == 9 | q8e == 98
	lab def noincome 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	lab val noincome noincome
	tab noincome, missing

* clean water
	gen nocleanwater = q8b
	replace nocleanwater = . if q8b == -1 | q8b == 9 | q8b == 98
	lab def nocleanwater 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	lab val nocleanwater nocleanwater
	tab nocleanwater, missing

* crime in home
	gen crime = q9a
	replace crime = . if q9a == -1 | q9a == 9 | q9a == 98
	lab def crime 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	lab val crime crime
	tab crime, missing
	
* Respondent attitude variables *

	gen hostile=q108a // hostile
	replace hostile=. if q108a==-1
	tab hostile, missing

	gen uncooperative=q108c // uncooperative
	replace uncooperative =. if q108c==-1
	tab uncooperative, missing

	gen impatient=q108d // impatient
	replace impatient=. if q108d==-1
	tab impatient, missing

	gen suspicious=q108e // suspicious
	replace suspicious =. if q108e==-1
	tab suspicious, missing
	
*******************************************************************************

* CONTROL VARIABLES

	recode q90 q1 (999 998 99 98 -1 = .)
	rename q90 edu // Education
	rename q1 age // age

	rename currint gender // male
	recode gender (2=0)
	lab def gender 0 "female" 1 "male"
	lab val gender gender

	gen urban = urbrur // urban
	recode urban (2=0)


*******************************************************************************

* LEADER ETHNICITY DATA

* respondent coethnicity with president
	sort country round	
	merge country round using "data/leader_ethnicity.dta", uniqusing
	drop if _merge~=3
	drop _merge

	gen coeth_leader=1 if tribe==leader_tribe & tribe~=. & leader_tribe~=.
	replace coeth_leader=0 if tribe~= leader_tribe & tribe~=. & leader_tribe ~=.

* enumerator coethnicity with president
	gen int_coeth_leader=1 if enumeth==leader_tribe & enumeth~=. 
	replace int_coeth_leader=0 if enumeth~=leader_tribe & leader_tribe~=.

	label copy LABAH trust
	label values etrust trust
	label values netrust trust


*******************************************************************************

* PLACEBO TEST VARIABLES


* Don't know, refuse to answer
	global r3 q82 q84c q84d q21 q37 q68a q57f q4a q4b q8a q55e q55f q65a q80a q80b q81 q30 q8e q8b q9a q31a q16
	foreach v in $r3 {
		gen `v'_dk=(`v'==9 | `v'==98)
	}

	gen q97_dk=(q97==9 | q97==8)
	gen q43a2_dk=(q43a2==98)
	egen totaldk=rowmean(*_dk)
	drop *_dk

* Refuse to answer on previous interviews
	foreach v in hholdse1 hholdse2 hholdse3 hholdse4 hholdse5 hholdse6 hholdse7 {
		gen `v'ref=(`v'==1)
	}
	egen prevref=rowtotal(*ref)

* ratio of refusals/interviews for each enumerator
	egen totalref=total(prevref) if noncoeth~=., by(enumid)
	egen completed=count(noncoeth) if noncoeth~=., by(enumid)
	gen ratio=totalref/completed
	egen enumtag = tag(round enumid) if noncoeth~=. 

* proportion of interviews that are noncoethnic
	egen totalnoncoeth=mean(noncoeth), by(enumid)


*******************************************************************************

	

