
*******************************************************************************

* GENERAL INFO
	* Project: Who’s Asking? Interviewer Coethnicity Effects in African Survey Data
	* Created: by Claire Adida, Karen Ferree, Dan Posner, and Amanda Robinson
	* Updated: 28 Feb 16 by Julia Clark

* DO FILE INFO
	* Auxilary .do file for AFPR_clean.do that cleans ABR4 data and merges in ethnicity data
	* Inputs: ABR4Data.dta, AB3_AB4_concordance79.dta, AB_enumerators.dta, pol_rel_dyads.dta, leader_ethnicity.dta

*******************************************************************************

* LOAD AND CLEAN DATA	

	use "data/ABR4Data.dta"

* generate AB round variable
	gen round=4

* rename within country weights variable to match R3	
	rename Withinwt withinwt

* create country dummies
	tab country, gen(dummy)
	rename dummy1 benin
	rename dummy2 botswana
	rename dummy3 burkina
	rename dummy4 capeverde
	rename dummy5 ghana
	rename dummy6 kenya
	rename dummy7 lesotho
	rename dummy8 liberia
	rename dummy9 madagascar
	rename dummy10 malawi
	rename dummy11 mali
	rename dummy12 mozambique
	rename dummy13 namibia
	rename dummy14 nigeria
	rename dummy15 senegal
	rename dummy16 safrica
	rename dummy17 tanzania
	rename dummy18 uganda
	rename dummy19 zambia
	rename dummy20 zimbabwe

* code countries which appear in R4 but not R3
	gen new4=0
	recode new4 (0=1) if burkina==1
	recode new4 (0=1) if liberia==1
	recode new4 (0=1) if zimbabwe==1
	
*******************************************************************************

* TREATMENT VARIABLES
	
* langauge questions
	recode q3 q114 (-1 995 998 999=.)
	gen resplang=q3
	rename q114 intlang
	rename q103 langused

* colang = respondent and interviewer speak same home language
	gen colang=1 if resplang==intlang
	replace colang=0 if resplang~=intlang
	la var colang "Colanguage Interviewer (resplang==intlang)"
	la def colang 0 "No" 1 "Yes"
	la val colang colang

* tribe question for R4
	recode q79 (995 998 999 990 -1 = .)
	recode q79 (797=788)
	rename q79 q79_4
	sort q79_4 // merge in R3 tribe codings for consistency
	merge q79_4 using "data/AB3_AB4_concordance79.dta", uniqusing

	gen tribe=q79_3 if new==0 // tribe or ethnic group
	replace tribe=q79_4 if new==1 // new codes for R4 countries not in R3
	replace tribe=tribe+1000 if new==1 & tribe<=994
	
	drop _merge

* add R3 variable labels, including newly created lables for R4 only countries
	do "code/q79label.do"
	lab val tribe q79 

* merge in R3 language codes for consistency
	rename q3 q3_4
	sort q3_4
	merge q3_4 using "data/AB3_AB4_concordance3.dta", uniqusing	
	drop _merge

* merge in enumerator ethnicity data (note: no R3 data for lesotho, mozambique, tanzania)
	sort round q110
	merge round q110 using "data/AB_enumerators.dta", uniqusing
	drop if country==. // drop the 657 enumerators from Round 4
	drop _merge

	recode enumeth (999 995=.) // enumerator ethnicity
	replace enumeth=enumeth+1000 if new==1 & enumeth<=994 // R3 tribal codes in R4-only countries
	lab val enumeth q79

* coethnicity/language variables
	gen coeth=1 if tribe==enumeth & tribe~=. & enumeth~=. // coethnic interviewer
	recode coeth (.=0) if tribe~=enumeth & tribe~=. & enumeth~=.
	lab val coeth colang

	recode coeth (0=1)(1=0), gen(noncoeth) // non-coethnic interviewer
	lab val noncoeth colang

	gen inhomelang=1 if resplang==langused // interview conducted in responent's home language
	replace inhomelang=0 if resplang~=langused
	la var inhomelang 

* create round-specif enum ids
	egen enumid=concat(round q110)

* merge in political relevance for resp, enum, and dyad
	egen dyad=concat(enumeth tribe) if enumeth~=. & tribe~=., punct(-)
	sort dyad
	merge dyad using "data/pol_rel_dyads.dta", uniqusing
	drop _merge

* respondent coethnicity with president
	sort country round
	merge country round using "data/leader_ethnicity.dta", uniqusing
	drop _merge

	gen coeth_leader=1 if tribe==leader_tribe & tribe~=. & leader_tribe~=.
	replace coeth_leader=0 if tribe~= leader_tribe & tribe~=. & leader_tribe ~=.

* enumerator coethnicity with president
	gen int_coeth_leader=1 if enumeth==leader_tribe & enumeth~=. 
	replace int_coeth_leader=0 if enumeth~=leader_tribe & leader_tribe~=.


*******************************************************************************

* DEPENDENT VARIABLES

* national versus ethnic identity
	gen idrank=q83
	recode idrank (9 98 -1 7 = .)
	recode idrank (.=5) if tribe==990
	recode idrank (.=1) if tribe==990
	recode idrank (1=0) (2=1) (3=2) (4=3) (5=4)
	la def idrank 0 "ethnic only" 1 "ethnic over national" 2 "equal" 3 "national over ethnic" 4 "national only", modify
	la val idrank idrank

* politicians should help community
	gen patronage=q17 // belief that politicians should help home community
	recode patronage (5=.) (-1=.) (9=.) (998=.)
	recode patronage (1=2)(4=3)
	recode patronage (2=0)(3=1)
	la def patronage 0 "against patronage" 1 "support patronage"
	la val patronage patronage

*support for democracy
	gen demosupp=q30
	recode demosupp (9 98 998 999 -1=.)
	recode demosupp (1 2=0)
	recode demosupp (3=1)
	la def demosupp 0 "demo not always best or doesn't matter" 1 "democracy best"
	la val demosupp demosupp

* approve of incumbent's performance
	gen performance=1 if q70a==3 | q70a==4
	replace performance=0 if performance==.
	replace performance=. if q70a==9 | q70a==998 | q70a==-1
	la def performance 0 "Disapprove" 1 "Approve"
	la val performance performance
	tab performance, missing
	
* interest in public affairs
	gen pubaffairs=q13
	replace pubaffairs=. if pubaffairs==-1
	replace pubaffairs=. if pubaffairs==998
	replace pubaffairs=. if pubaffairs==9
	tab pubaffairs, missing

* community meeting
	gen meeting=q23a
	replace meeting=. if meeting==-1
	replace meeting=. if meeting==998
	replace meeting=. if meeting==9
	tab meeting, missing

* Factual knowledge of MP
	gen knows_MP = 0 if q41a2 < 3 | q41a2 == 9
	replace knows_MP = 1 if q41a2 == 3
	replace knows_MP = . if q41a2==-1 | q41a2==98
	lab def knows_MP 0 "does not know MP" 1 "knows MP"
	lab val knows_MP knows_MP
	tab knows_MP, missing
	
* Economic conditions of country
	gen ec_conditions_ctry = q4a
	replace ec_conditions_ctry = . if q4a==-1 | q4a==9 | q4a==998
	la def ec_conditions_ctry 1 "very bad" 2 "fairly bad" 3 "neither good nor bad" 4 "fairly good" 5 "very good"
	la val ec_conditions_ctry ec_conditions_ctry
	tab ec_conditions_ctry, missing

* Personal economic conditions
	gen ec_conditions_self = q4b
	replace ec_conditions_self = . if q4b==-1 | q4b==9 | q4b==998
	la def ec_conditions_self 1 "very bad" 2 "fairly bad" 3 "neither good nor bad" 4 "fairly good" 5 "very good"
	la val ec_conditions_self ec_conditions_self
	tab ec_conditions_self, missing

* Not enough food to eat
	gen notenoughfood = q8a
	replace notenoughfood = . if q8a==-1 | q8a==9 | q8a==998
	la def notenoughfood 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	la val notenoughfood notenoughfood
	tab notenoughfood, missing

* Trust ruling party
	gen trust_rulingparty = q49e
	replace trust_rulingparty =  . if q49e==-1 | q49e==9 | q49e==998
	la def trust_rulingparty 0 "not at all" 1 "just a little" 2 "somewhat" 3 "a lot"
	la val trust_rulingparty trust_rulingparty
	tab trust_rulingparty, missing

* Trust opposition parties
	gen trust_opposition = q49f
	replace trust_opposition =  . if q49f==-1 | q49f==9 | q49f==998
	la def trust_opposition 0 "not at all" 1 "just a little" 2 "somewhat" 3 "a lot"
	la val trust_opposition trust_opposition
	tab trust_opposition, missing

* How well is government managing economy
	gen gov_manage_economy = q57a
	replace gov_manage_economy = . if q57a==-1 | q57a==9 | q57a==998
	la def gov_manage_economy 1 "very badly" 2 "fairly badly" 3 "fairly well" 4 "very well"
	lab val gov_manage_economy gov_manage_economy 
	tab gov_manage_economy, missing

* Economic conditions of group versus other groups
	gen ecconditions_group = q80
	replace ecconditions_group = . if q80==-1 | q80==7 | q80==9 | q80==998
	recode ecconditions_group (1=5)(2=4)(3=3)(5=1)(4=2)
	lab def ecconditions_group 5 "much better" 4 "better" 3 "same" 2 "worse" 1 "much worse"
	lab val ecconditions_group ecconditions_group
	tab ecconditions_group, missing

* Political influence of group versus other groups
	gen polinfluence_group = q81
	replace polinfluence_group = . if q81==-1 | q81==7 | q81==9 | q81==998
	recode polinfluence_group (1=5)(2=4)(3=3)(5=1)(4=2)
	lab def polinfluence_group 5 "much better" 4 "better" 3 "same" 2 "worse" 1 "much worse"
	lab val polinfluence_group polinfluence_group
	tab polinfluence_group, missing

* Group treated unfairly by government
	gen treatedunfairly_group = q82
	replace treatedunfairly_group = . if q82==-1 | q82==7 | q82==9 | q82==998
	lab def treatedunfairly_group 0 "never" 1 "sometimes" 2 "often" 3 "always"
	lab val treatedunfairly_group treatedunfairly_group
	tab treatedunfairly_group, missing

* Friend/relative died of AIDS
	gen aids = q95
	replace aids =. if q95==-1 | q95==8 | q95==9
	lab def aids 0 "no" 1 "yes"
	lab val aids aids
	tab aids, missing

* Voted in last election
	gen voted = 1 if q23d  == 1
	replace voted = 0 if q23d == 0 | q23d == 2 | q23d == 3 | q23d == 4 |q23d == 5 | q23d == 6
	replace voted = . if q23d==-1 | q23d==9 | q23d==998
	lab def voted 0 "did not vote" 1 "voted"
	lab val voted voted
	tab voted, missing

* cash income
	gen noincome = q8e
	replace noincome = . if q8e == -1 | q8e == 9 | q8e == 998
	lab def noincome 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	lab val noincome noincome
	tab noincome, missing

* clean water
	gen nocleanwater = q8b
	replace nocleanwater = . if q8b == -1 | q8b == 9 | q8b == 998
	lab def nocleanwater 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	lab val nocleanwater nocleanwater
	tab nocleanwater, missing

* crime in home
	gen crime = q9a
	replace crime = . if q9a == -1 | q9a == 9 | q9a == 998
	lab def crime 0 "never" 1 "just once or twice" 2 "several times" 3 "many times" 4 "always"
	lab val crime crime
	tab crime, missing	
	
* Respondent attitude variables *

	gen hostile=q108a // hostile
	replace hostile =. if q108a==-1
	tab hostile, missing

	gen uncooperative=q108c // uncooperative
	replace uncooperative=. if q108c==-1
	tab uncooperative, missing

	gen impatient=q108d // impatient
	replace impatient=. if q108d==-1
	tab impatient, missing

	gen suspicious =q108e // suspicious
	replace suspicious =. if q108e==-1
	tab suspicious, missing
	
*******************************************************************************

* CONTROL VARIABLES

* gender, age, urban, edu

	recode q89 q1 (999 998 99 98 -1 = .)
	rename q89 edu // Education
	rename q1 age // age

	rename thisint gender // male
	recode gender (2=0)
	la def gender 0 "female" 1 "male"
	la val gender gender

	gen urban = urbrur // urban
	recode urban (2=0)

	
*******************************************************************************

* PLACEBO TEST VARIABLES

* Don't know, refuse to answer
	global r4 q83 q17 q30 q70a q4a q4b q8a q49e q49f q57a q80 q81 q82 q23d q8e q8b q9a q23a q13
	foreach v in $r4 {
		gen `v'_dk=(`v'==9 | `v'==998)
	}

	gen q95_dk=(q95==9 | q97==8)
	gen q41a2_dk=(q41a2==998)
	egen totaldk=rowmean(*_dk)
	drop *_dk

* Refuse to answer on on previous interviews
	foreach v in nocall_1 nocall_2 nocall_3 nocall_4 nocall_5 nocall_6 nocall_7 {
		gen `v'ref=(`v'==1)
	}
	egen prevref=rowtotal(*ref)

* ratio of refusals/interviews for each enumerator
	egen totalref=total(prevref) if noncoeth~=., by(enumid)
	egen completed=count(noncoeth) if noncoeth~=., by(enumid)
	gen ratio=totalref/completed
	egen enumtag = tag(round enumid) if noncoeth~=. 

* proportion of interviews that are noncoethnic
	egen totalnoncoeth=mean(noncoeth), by(enumid)


*******************************************************************************





